*Frank Baumgartner
*Jan 2, 2020
*Replication files for Policy Studies Journal, Intersectional Encounters: Representative Bureaucracy and the Routine Traffic Stop
*This do-file replicates the analysis reported in the Appendix

cd h:\
use Charlotte1617.dta, clear

*Table A-1, stop rates by stop purpose
tab reason_for_stop search, row

*Table A-2, Replication of Table 1 while excluding Investigation and DWI stops
drop if reason_for_stop=="Investigation            "
drop if reason_for_stop=="Driving While Impaired   "
save Charlotte1617-no-Inv-no-DWI-stops.dta, replace

use Charlotte1617-no-Inv-no-DWI-stops.dta, clear

***For Table 1 (A-2):

tab search
tab search drace, col
tab search driver_gender, col
tab search driverLT35, col
tab search safetystop, col
tab search officer_race, col
tab search officer_gender, col
tab search offRG4, col miss
tab search officeryrs, col
tab search if owdw==1
tab search if owdb==1
tab search if owdo==1
tab search if obdw==1
tab search if obdb==1
tab patrol search , row

***End of Table 1


***Table 2, logistic regressions

logistic search offwm officer_years_of_service investstop driverLT35 i.dRG8  i.patrol
logistic arrest offwm officer_years_of_service investstop driverLT35 i.dRG8  i.patrol
logistic drysearch offwm officer_years_of_service investstop driverLT35 i.dRG8  i.patrol

*End of Table 2

*Table A-4, replicating Table 3, search rates, excluding Investigatory and DWI stops

tab DR search, row
tab DS search, row
tab DA search, row
tab owm search, row
tab offyears search, row
tab stopinvest search, row
tab area1 search, row
tab area2 search, row

*Table A-5, replicating Table 4
tab Target search, row


*Figure A-1, 


use Charlotte1617-no-Inv-no-DWI-stops.dta, clear
collapse (sum) stop search arrest drysearch (last) patrol , by(cmpd_division)
gen searchrate = (search*100)/stop
gen arrestrate = (arrest*100)/stop
gen drysearchrate = (drysearch*100)/stop
drop if patrol==0
rename patrol District
save District-search-arrest-rates-no-Inv-no-DWI-stops.dta, replace



import excel using TractsToDistricts.xlsx, sheet(Sheet2) firstrow clear
drop if District == .
rename TotalPopulation pop
rename AverageHouseholdIncomeIn201 inc
drop F
save Tracts.dta, replace

use Tracts.dta, clear
collapse (sum) pop , by(District)
rename pop DistrictPop
joinby District using Tracts.dta , unm(both)
gen PopShare = pop/DistrictPop
gen IncomeShare = PopShare*inc
collapse (sum) pop PopShare IncomeShare (last) Division, by(District)
rename IncomeShare Income
drop PopShare
gen IncomePerCapita = Income/pop
joinby District using District-search-arrest-rates-no-Inv-no-DWI-stops.dta, unm(both)
save Districts-no-Inv-no-DWI-stops.dta, replace

use Districts.dta, clear
drop _merge
joinby District using District-search-arrest-rates.dta, unm(both)
drop _merge
gen inc = Income/1000

format Income %9.0fc
#delimit ;
scatter searchrate inc,
mlstyle(color(gs0)) msymbol(circle) mfcolor(black) 
graphregion(color(white)) 
ylabel(0(3)12, nogrid)
yscale() 
ytitle("Percent") 
xscale()
xlabel(40(20)160)
xtitle("Average Household Income (Thousands)")
caption("")
title(A. Search, position(11) span)
;

graph save FigA1a.gph,  replace

#delimit ;
scatter arrestrate inc,
mlstyle(color(gs0)) msymbol(circle) mfcolor(black) 
graphregion(color(white)) 
ylabel(0(3)12, nogrid)
yscale() 
ytitle("Percent") 
xscale()
xlabel(40(20)160)
xtitle("Average Household Income (Thousands)")
caption("")
title(B. Arrest, position(11) span)
;

graph save  FigA1b.gph, replace


#delimit ;
scatter drysearchrate inc,
mlstyle(color(gs0)) msymbol(circle) mfcolor(black) 
graphregion(color(white)) 
ylabel(0(3)12, nogrid)
yscale() 
ytitle("Percent") 
xscale()
xlabel(40(20)160)
xtitle("Average Household Income  (Thousands)")
caption("")
title(C. Fruitless Search, position(11) span)
;

graph save  FigA1c.gph ,  replace

graph combine FigA1a.gph FigA1b.gph FigA1c.gph, graphregion(color(white)) colf r(1) col(3) xsize(6.5) ysize(2) ycommon altshrink
graph export "FigA1.png", width(3000) replace
graph export "FigA1.eps",  replace

corr searchrate arrestrate drysearchrate Income

***End of Figure A-1

***Figure A-2, 
use Charlotte1617-no-Inv-no-DWI-stops.dta, clear

gen wmstop = stop if offRG6==1
gen wmsearch = search if offRG6==1
gen wmarrest = arrest if offRG6==1
gen wmdrysearch = drysearch if offRG6==1
gen bmstop = stop if offRG6==3
gen bmsearch = search if offRG6==3
gen bmarrest = arrest if offRG6==3
gen bmdrysearch = drysearch if offRG6==3
gen driver = "White Male" if dRG8==5
replace driver = "Other Race Male" if dRG8>6
replace driver = "Black Male" if dRG8==6
replace driver = "White Female" if dRG8==1
replace driver = "Other Race Female" if dRG8> 2 & dRG8 < 5
replace driver = "Black Female" if dRG8==2

collapse (sum) wmstop wmsearch wmarrest wmdrysearch bmstop bmsearch bmarrest bmdrysearch, by(driver)
gen wmsearchrate=(wmsearch*100)/wmstop
gen wmarrestrate=(wmarrest*100)/wmstop
gen wmdrysearchrate=(wmdrysearch*100)/wmstop
gen bmsearchrate=(bmsearch*100)/bmstop
gen bmarrestrate=(bmarrest*100)/bmstop
gen bmdrysearchrate=(bmdrysearch*100)/wmstop
save OffDrivSearchArrestRates-no-Inv-no-DWI-stops.dta, replace


use OffDrivSearchArrestRates-no-Inv-no-DWI-stops, clear
gen order = 1 if driver == "White Male"
replace order = 2 if driver == "Other Race Male" 
replace order = 3 if driver == "Black Male" 
replace order = 4 if driver == "White Female" 
replace order = 5 if driver == "Other Race Female" 
replace order = 6 if driver == "Black Female" 



#delimit;
graph bar wmsearchrate bmsearchrate , over(driver, sort(order) label(angle(30) labsize(small)))
graphregion(color(white))
bar(1 , color(gs0))
bar(2 , color(gs12))
blabel(bar, format(%6.1f) size(small))
ytitle("Percent")
b1title("")
legend(off)
ylabel(, nogrid)
note("")
title(A. Search, position(11) span)
;

graph save  FigA2a.gph ,  replace


#delimit;
graph bar wmarrestrate bmarrestrate , over(driver, sort(order) label(angle(30) labsize(small)))
graphregion(color(white))
bar(1 , color(gs0))
bar(2 , color(gs12))
blabel(bar, format(%6.2f) size(small))
ytitle("Percent")
b1title("")
legend(off)
ylabel(, nogrid)
note("")
title(B. Arrest, position(11) span)
;

graph save  FigA2b.gph ,  replace


#delimit;
graph bar wmdrysearchrate bmdrysearchrate , over(driver, sort(order) label(angle(30) labsize(small)))
graphregion(color(white))
bar(1 , color(gs0))
bar(2 , color(gs12))
blabel(bar, format(%6.1f) size(small))
ytitle("Percent")
b1title("")
legend(off)
ylabel(, nogrid)
note("")
title(C. Fruitless Search, position(11) span)
;

graph save  FigA2c.gph ,  replace

graph combine FigA2a.gph FigA2b.gph FigA2c.gph, graphregion(color(white)) colf r(1) col(3) xsize(6.5) ysize(2) ycommon altshrink
graph export "FigA2.png", width(3000) replace
graph export "FigA2.eps", replace

**Figure 3A, predicted probabilities by Driver Race and Gender
***Figure 3, Predicted rates by Driver characteristics from Table 2

use Charlotte1617-no-Inv-no-DWI-stops.dta, clear

logistic search offwm i.dRG8a driverLT35 investstop officer_years_of_service i.patrol
margins dRG8a  , at((means) _all (max) driverLT35 offwm investstop (min) officer_years_of_service (asobserved) dRG8a ) post

#delimit ;
marginsplot , recast(scatter ) 
graphregion(color(white)) 
title("")
xtitle(Driver Race and Gender)
xlabel(1 "Black Male" 2 "Hispanic Male" 3 "White Male" 4 "Other Race Male"
5  "Black Female" 6 "White Female" 7 "Hispanic Female" 8 "Other Race Female", angle(30) labsize(small))
aspectratio(.5)
scheme(s1mono)
ylabel(, nogrid)
ytitle(Probability)
title(A. Search, position(11) span)
;

graph save FigA3a.gph, replace

***Arrest version of Figure 3
**Margins plots for predicted effects from Model 3 of Table 2
*for the table:
logistic arrest offwm driverLT35 investstop officer_years_of_service i.dRG8 i.patrol

*for the margins plot, with categories in different order
logistic arrest offwm i.dRG8a driverLT35 investstop officer_years_of_service i.patrol
margins dRG8a  , at((means) _all (max) driverLT35 offwm investstop (min) officer_years_of_service (asobserved) dRG8a ) post

#delimit ;
marginsplot , recast(scatter ) 
graphregion(color(white)) 
title("")
xtitle(Driver Race and Gender)
xlabel(1 "Black Male" 2 "Hispanic Male" 3 "White Male" 4 "Other Race Male"
5  "Black Female" 6 "White Female" 7 "Hispanic Female" 8 "Other Race Female", angle(30) labsize(small))
aspectratio(.5)
scheme(s1mono)
ylabel(, nogrid)
ytitle(Probability)
title(B. Arrest, position(11) span)
;

graph save FigA3b.gph, replace

***Fruitless search version of Figure 3
**Margins plots for predicted effects from Model 3 of Table 2
*for the table:
logistic drysearch offwm driverLT35 investstop officer_years_of_service i.dRG8 i.patrol

*for the margins plot, with categories in different order
logistic drysearch offwm i.dRG8a driverLT35 investstop officer_years_of_service i.patrol
margins dRG8a  , at((means) _all (max) driverLT35 offwm investstop (min) officer_years_of_service (asobserved) dRG8a ) post

#delimit ;
marginsplot , recast(scatter ) 
graphregion(color(white)) 
title("")
xtitle(Driver Race and Gender)
xlabel(1 "Black Male" 2 "Hispanic Male" 3 "White Male" 4 "Other Race Male"
5  "Black Female" 6 "White Female" 7 "Hispanic Female" 8 "Other Race Female", angle(30) labsize(small))
aspectratio(.5)
scheme(s1mono)
ylabel(, nogrid)
ytitle(Probability)
title(C. Fruitless Search, position(11) span)
;

graph save FigA3c.gph, replace

graph combine FigA3a.gph FigA3b.gph FigA3c.gph, graphregion(color(white)) colf r(1) col(3) xsize(6.5) ysize(2) ycommon altshrink
graph export "FigA3.png", width(3000) replace
graph export "FigA3.eps", replace


**Figure 4A, predicted probabilities by Officer Race and Gender
*Figure 4, officer characteristics varied
logistic search i.offRG6 i.dRG8a driverLT35 investstop officer_years_of_service i.patrol

margins offRG6  , at((means) _all (max) driverLT35  investstop (min) officer_years_of_service (asobserved) offRG6 ) post

#delimit ;
marginsplot , recast(scatter ) 
graphregion(color(white)) 
title("")
xtitle(Officer Race and Gender)
xlabel(1 "White Male" 2 "Other Race Male" 3 "Black Male" 4 "White Female" 5 "Other Race Female" 6 "Black Female" , labsize(small) angle(30))
aspectratio()
scheme(s1mono)
ylabel(, nogrid)
ytitle(Probability)
title(A. Search, position(11) span)
;

graph save FigA4a.gph, replace

***Arrest version:
*Figure 4, officer characteristics varied
logistic arrest i.offRG6 i.dRG8a driverLT35 investstop officer_years_of_service i.patrol

margins offRG6  , at((means) _all (max) driverLT35  investstop (min) officer_years_of_service (asobserved) offRG6 ) post

#delimit ;
marginsplot , recast(scatter ) 
graphregion(color(white)) 
title("")
xtitle(Officer Race and Gender)
xlabel(1 "White Male" 2 "Other Race Male" 3 "Black Male" 4 "White Female" 5 "Other Race Female" 6 "Black Female" , labsize(small) angle(30))
aspectratio()
scheme(s1mono)
ylabel(, nogrid)
ytitle(Probability)
title(B. Arrest, position(11) span)
;

graph save FigA4b.gph, replace

***Fruitless search version:
*Figure 4, officer characteristics varied
logistic drysearch i.offRG6 i.dRG8a driverLT35 investstop officer_years_of_service i.patrol

margins offRG6  , at((means) _all (max) driverLT35  investstop (min) officer_years_of_service (asobserved) offRG6 ) post

#delimit ;
marginsplot , recast(scatter ) 
graphregion(color(white)) 
title("")
xtitle(Officer Race and Gender)
xlabel(1 "White Male" 2 "Other Race Male" 3 "Black Male" 4 "White Female" 5 "Other Race Female" 6 "Black Female" , labsize(small) angle(30))
aspectratio()
scheme(s1mono)
ylabel(, nogrid)
ytitle(Probability)
title(C. Fruitless Search, position(11) span)
;

graph save FigA4c.gph, replace

graph combine FigA4a.gph FigA4b.gph FigA4c.gph, graphregion(color(white)) colf r(1) col(3) xsize(6.5) ysize(2) ycommon altshrink
graph export "FigA4.png", width(3000) replace
graph export "FigA4.eps", replace
**Figure 5A, search rates by number of targeted characteristics

*Figure 5

gen search100 = search*100
gen arrest100 = arrest*100
gen drysearch100 = drysearch*100
#delimit;
graph bar search100 , over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.1f))
ytitle("Percent")
b1title("Number of Targeted Characteristics")
legend()
ylabel(, nogrid)
title(A. Search, position(11) span)
;

graph save FigA5a.gph, replace
*Arrest

*Figure 5
#delimit;
graph bar arrest100 , over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.1f))
ytitle("Percent")
b1title("Number of Targeted Characteristics")
legend()
ylabel(, nogrid)
title(B. Arrest, position(11) span)
;

graph save FigA5b.gph, replace


*Fruitless Search

*Figure 5
#delimit;
graph bar drysearch100 , over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.1f))
ytitle("Percent")
b1title("Number of Targeted Characteristics")
legend()
ylabel(, nogrid)
title(C. Fruitless Search, position(11) span)
;

graph save FigA5c.gph, replace

graph combine FigA5a.gph FigA5b.gph FigA5c.gph, graphregion(color(white)) colf r(1) col(3) xsize(6.5) ysize(2) ycommon altshrink
graph export "FigA5.png", width(3000) replace
graph export "FigA5.eps", replace


**Table A-6 Regressions predicting a search

clear

use Charlotte0216.dta, clear
gen Filter1 = 1 if purpose==3 | purpose==8
gen Filter2 = 1 if SearchType==2 | SearchType==4 | SearchType==5 
recode Filter1 Filter2 (.=0)
tab1 Filter*, miss
tab Filter1 purpose
tab Filter2 SearchType
tab purpose searchoccur, row miss
tab purpose searchoccur if Filter2==0, row miss

gen RG8 = race2 if gender==0
gen RGx = race2+4 if gender==1
replace RG8 = RGx if RG8==.
tab1 RG*, miss

*Baseline model for searches in Charlotte, call years together
logistic searchoccur i.RG8 Age i.purpose i.hour 
*Just for 2016
logistic searchoccur i.RG8 Age i.purpose i.hour if year==2016
*Excluding DWI and Investigation stops
logistic searchoccur i.RG8 Age i.purpose i.hour if year==2016 & Filter1==0
*Also excluding searches other than consent or probable cause
logistic searchoccur i.RG8 Age i.purpose i.hour if year==2016 & Filter1==0 & Filter2==0

*So from that we can extract the coefficient for being a black male: 5.52, 6.87, 7.25, 7.83
*So, actually they go up when we do these controls.
*This answers the question from the reviewer about other types of stops and non-discretionary searches.


*Table 3A and 3B, replicating Table 3 in the text for Arrests and Fruitless searches
use Charlotte1617.dta, clear

tab DR arrest, row
tab DS arrest, row
tab DA arrest, row
tab owm arrest, row
tab offyears arrest, row
tab stopinvest arrest, row
tab area1 arrest, row
tab area2 arrest, row

tab DR drysearch, row
tab DS drysearch, row
tab DA drysearch, row
tab owm drysearch, row
tab offyears drysearch, row
tab stopinvest drysearch, row
tab area1 drysearch, row
tab area2 drysearch, row


*Table 4-A average number of additional targeted characteristics, by group 
*make variable for relevant identities
*calculate number of additional targets, for each identity group
gen Target2 = DR+DS+DA+offwm+offyears+stopinvest+area1+area2
gen TargetDR1 = DS+DA+offwm+offyears+stopinvest+area1+area2 if DR==1
gen TargetDR0 = DS+DA+offwm+offyears+stopinvest+area1+area2 if DR==0
gen TargetDS1 = DR+DA+offwm+offyears+stopinvest+area1+area2 if DS==1
gen TargetDS0 = DR+DA+offwm+offyears+stopinvest+area1+area2 if DS==0
gen TargetDA1 = DR+DS+offwm+offyears+stopinvest+area1+area2 if DA==1
gen TargetDA0 = DR+DS+offwm+offyears+stopinvest+area1+area2 if DA==0
gen Targetoffwm1 = DR+DS+DA+offyears+stopinvest+area1+area2 if offwm==1
gen Targetoffwm0 = DR+DS+DA+offyears+stopinvest+area1+area2 if offwm==0
gen Targetoffyears1 = DR+DS+DA+offwm+stopinvest+area1+area2 if offyears==1
gen Targetoffyears0 = DR+DS+DA+offwm+stopinvest+area1+area2 if offyears==0
gen Targetstopinvest1 = DR+DS+DA+offwm+offyears+area1+area2 if stopinvest==1
gen Targetstopinvest0 = DR+DS+DA+offwm+offyears+area1+area2 if stopinvest==0
gen Targetarea11 = DR+DS+DA+offwm+offyears+stopinvest+area2 if area1==1
gen Targetarea10 = DR+DS+DA+offwm+offyears+stopinvest+area2 if area1==0
gen Targetarea21 = DR+DS+DA+offwm+offyears+stopinvest+area1 if area2==1
gen Targetarea20 = DR+DS+DA+offwm+offyears+stopinvest+area1 if area2==0

*sum that target variable for each identity group
sum Target*

*Figure 5
*White drivers
#delimit;
graph bar drysearch if DR==0, over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.3f))
ytitle("Probability of Fruitless Search")
b1title("Number of Targeted Characteristics")
legend()
ylabel(0(.1).3, nogrid)
caption("White drivers")
;
graph save Fig5A-a.gph, replace 


*White female drivers
#delimit;
graph bar drysearch if DR==0 & DS==0, over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.3f))
ytitle("Probability of Fruitless Search")
b1title("Number of Targeted Characteristics")
legend()
ylabel(0(.1).3, nogrid)
caption("White female drivers")
;
graph save Fig5A-b.gph, replace


*older White female drivers
#delimit;
graph bar drysearch if DR==0 & DS==0 & DA==0, over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.3f))
ytitle("Probability of Fruitless Search")
b1title("Number of Targeted Characteristics")
legend()
ylabel(0(.1).3, nogrid)
caption("Older White female drivers")
;
graph save Fig5A-c.gph, replace

graph combine Fig5A-a.gph Fig5A-b.gph Fig5A-c.gph, graphregion(color(white)) colf r(1) col(3) xsize(6.5) ysize(2) ycommon altshrink
graph export "Fig5A.png", width(3000) replace
graph export "Fig5A.eps", replace

*Figure 5-B


*Black drivers
#delimit;
graph bar drysearch if DR==1, over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.3f))
ytitle("Probability of Fruitless Search")
b1title("Number of Targeted Characteristics")
legend()
ylabel(0(.1).3, nogrid)
caption("Black drivers")
;
graph save Fig5B-a.gph, replace


*Black male drivers
#delimit;
graph bar drysearch if DR==1 & DS==1, over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.3f))
ytitle("Probability of Fruitless Search")
b1title("Number of Targeted Characteristics")
legend()
ylabel(0(.1).3, nogrid)
caption("Black male drivers")
;
graph save Fig5B-b.gph, replace

*young Black male drivers
#delimit;
graph bar drysearch if DR==1 & DS==1 & DA==1, over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.3f))
ytitle("Probability of Fruitless Search")
b1title("Number of Targeted Characteristics")
legend()
ylabel(0(.1).3, nogrid)
caption("Young Black male drivers")
;
graph save Fig5B-c.gph, replace

*young Black male drivers, white male officer
#delimit;
graph bar drysearch if DR==1 & DS==1 & DA==1 & offwm==1, over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.3f))
ytitle("Probability of Fruitless Search")
b1title("Number of Targeted Characteristics")
legend()
ylabel(0(.1).3, nogrid)
caption("Young Black male drivers, White male officer")
;
graph save Fig5B-d.gph, replace

*young Black male drivers, Metro district
#delimit;
graph bar drysearch if DR==1 & DS==1 & DA==1 & area2==1, over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.3f))
ytitle("Probability of Fruitless Search")
b1title("Number of Targeted Characteristics")
legend()
ylabel(0(.1).3, nogrid)
caption("Young Black male drivers, Metro district")
;
graph save Fig5B-e.gph, replace

*young Black male drivers, Metro district, white male officer
#delimit;
graph bar drysearch if DR==1 & DS==1 & DA==1 & area2==1 & offwm==1, over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.3f))
ytitle("Probability of Fruitless Search")
b1title("Number of Targeted Characteristics")
legend()
ylabel(0(.1).3, nogrid)
caption("Young Black male drivers, Metro district, White male officer")
;
graph save Fig5B-f.gph, replace

graph combine Fig5B-a.gph Fig5B-d.gph Fig5B-b.gph Fig5B-e.gph Fig5B-c.gph Fig5B-f.gph, graphregion(color(white)) colf r(2) col(3) xsize(6.5) ysize(4) ycommon altshrink
graph export "Fig5B.png", width(3000) replace
graph export "Fig5B.eps", replace

*Figure 5C

*Drivers stopped in the low search areas
#delimit;
graph bar drysearch if area1==0, over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.3f))
ytitle("Probability of Fruitless Search")
b1title("Number of Targeted Characteristics")
legend()
ylabel(0(.1).3, nogrid)
caption("Drivers stopped in low-search districts")
;
graph save Fig5C-a.gph, replace

*Drivers stopped in the Metro district
#delimit;
graph bar drysearch if area2==1, over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.3f))
ytitle("Probability of Fruitless Search")
b1title("Number of Targeted Characteristics")
legend()
ylabel(0(.1).3, nogrid)
caption("Drivers stopped in the Metro district")
;
graph save Fig5C-b.gph, replace


graph combine Fig5C-a.gph Fig5C-b.gph, graphregion(color(white)) colf r(1) col(3) xsize(4.6) ysize(2) ycommon altshrink
graph export "Fig5C.png", width(3000) replace
graph export "Fig5C.eps", replace
