*Frank Baumgartner
*Jan 1, 2020
*Replication files for Policy Studies Journal, Intersectional Encounters: Representative Bureaucracy and the Routine Traffic Stop

*Extract all files from "PSJ-OfficerEffects-replication-files.zip" to a working directory

*Part 1. Read the raw file as provided from the Charlotte police open data web site and save as a Stata dta file.
* Charlotte policing data from the city's open data portal: http://clt-charlotte.opendata.arcgis.com/datasets/c458bca429b542bbb31130c23510628a_7, downloaded September 18, 2018

cd H:\

import delimited using Officer_Traffic_Stops.csv, varnames(1) clear
split ïmonth_of_stop, gen(yearmon) parse("/")
rename yearmon1 year
rename yearmon2 month
destring year, replace
destring month, replace
drop ïmonth_of_stop editor editdate creator creationdate objectid
order year month


*generate a clean race / gender variable with 4 categories
gen offgen = 0 if officer_gender=="Male"
recode offgen (.=1) if officer_gender=="Female"
gen offrace = 1 if officer_race=="White"
recode offrace (.= 2) if officer_race=="Black/African American"

*white / nonwhite officer
gen offwhite = 1 if officer_race=="White"
recode offwhite (.=0)

gen offRG4 = 1 if offrace==1&offgen==0
replace offRG4 = 2 if offrace==2&offgen==0
replace offRG4 = 3 if offrace==1&offgen==1
replace offRG4 = 4 if offrace==2&offgen==1

sort officer_gender
by officer_gender: tab officer_race offRG4

gen offwm = 1 if offRG4==1
gen offbm = 1 if offRG4==2
gen offwf = 1 if offRG4==3
gen offbf = 1 if offRG4==4
recode offwm (.=0) if offRG4 <5
recode offbm (.=0) if offRG4 <5
recode offwf (.=0) if offRG4 <5
recode offbf (.=0) if offRG4 <5

*clean driver race variable
gen driverW = 1 if driver_race=="White" & driver_ethnicity=="Non-Hispanic"
gen driverB = 1 if driver_race=="Black" & driver_ethnicity=="Non-Hispanic"
gen driverH = 1 if driver_ethnicity=="Hispanic"

gen drace = 1 if driverW==1
recode drace (.=2) if driverB==1
recode drace (.=3) if driverH==1
recode drace (.=4)

tab1 offRG4 offwhite offrace drace

*interact officer and driver race
gen owdw = 1 if offrace==1&drace==1
gen owdb = 1 if offrace==1&drace==2
gen owdo = 1 if offrace==1&drace>2
gen obdw = 1 if offrace==2&drace==1 
gen obdb = 1 if offrace==2&drace==2
recode owdw owdb owdo obdw obdb (.=0)

tab1 owdw owdb owdo obdw obdb

gen driverLT35 = 1 if driver_age<35
recode driverLT35 (.=0) if driver_age>34.999
tab driverLT35
tab reason_for_stop

*officer years of service <5 5-13, 14+ (equal thirds)
egen officeryrs = cut(officer_years_of_service), g(3)


gen safetystop = 0
gen DWIStop = 1 if reason_for_stop=="Driving While Impaired   "
gen SafeMovementStop = 1 if reason_for_stop=="Safe Movement            "
gen SpeedingStop = 1 if reason_for_stop=="Speeding                 "
gen StopLightStop = 1 if reason_for_stop=="Stop Light/Sign          "
recode DWIStop SafeMovementStop SpeedingStop StopLightStop (.=0)
tab1 DWIStop SafeMovementStop SpeedingStop StopLightStop
recode safetystop (0=1) if DWIStop==1 | SafeMovementStop==1 | SpeedingStop==1 | StopLightStop==1
tab safetystop

gen search=0
recode search (0=1) if was_a_search_conducted=="Yes"

gen gender=0
recode gender (0=1) if driver_gender=="Male"

*get the patrol divisions into numeric format

gen patrol = 0
recode patrol (0=1) if cmpd_division=="Central Division"
recode patrol (0=2) if cmpd_division=="Eastway Division"
recode patrol (0=3) if cmpd_division=="Freedom Division"
recode patrol (0=4) if cmpd_division=="Hickory Grove Division"
recode patrol (0=5) if cmpd_division=="Independence Division"
recode patrol (0=6) if cmpd_division=="Metro Division"
recode patrol (0=7) if cmpd_division=="North Division"
recode patrol (0=8) if cmpd_division=="North Tryon Division"
recode patrol (0=9) if cmpd_division=="Providence Division"
recode patrol (0=10) if cmpd_division=="South Division"
recode patrol (0=11) if cmpd_division=="Steele Creek Division"
recode patrol (0=12) if cmpd_division=="University City Division"
recode patrol (0=13) if cmpd_division=="Westover Division"

tab patrol search , row
tab patrol offrace , row
tab patrol drace , row

gen dgrace = gender*drace
gen investstop = 1 if safetystop==0
recode investstop (.=0) if safetystop==1
recode offwm (.=0)

*revised race and gender interaction for model 2 and 3
gen dRG8=drace if gender==0
recode dRG8 (.=5) if gender==1 & drace==1
recode dRG8 (.=6) if gender==1 & drace==2
recode dRG8 (.=7) if gender==1 & drace==3
recode dRG8 (.=8) if gender==1 & drace==4


*re-order the race and geender categories to be most effective visually
gen dRG8a = 1 if dRG8==6
recode dRG8a (.=2) if dRG8==7
recode dRG8a (.=3) if dRG8==5
recode dRG8a (.=4) if dRG8==8
recode dRG8a (.=5) if dRG8==2
recode dRG8a (.=6) if dRG8==1
recode dRG8a (.=7) if dRG8==3
recode dRG8a (.=8) if dRG8==4

*By officer characteristics
tab offRG4, miss
gen offRG5 = offRG4
recode offRG5 (.=5)


gen offRG5a = 1 if offRG5==1
recode offRG5a (. = 2) if offRG5==5
recode offRG5a (. = 3) if offRG5==3
recode offRG5a (. = 4) if offRG5==2
recode offRG5a (. = 5) if offRG5==4


gen offRG6 = 1 if offRG5a==1
recode offRG6 (.=2) if offRG5a==2 & officer_gender=="Male"
recode offRG6 (.=3) if offRG5a==4
recode offRG6 (.=4) if offRG5a==3
recode offRG6 (.=5) if offRG5a==2 & officer_gender=="Female"
recode offRG6 (.=6) if offRG5a==5
tab offRG5a offRG6
tab offRG6 search, row

*Table 3 and 4 and Figure 3, targets

*Variables to vary:
*Driver race B/W
*Driver gender M / F
*Driver young / old
*Officer WM or Not
*Officer Rookie / Veteran split at median years of service
*Invst - Safety stop
*High search area = Metro division v. low search area (South, Providence, North.

*Then the combinations of all of these, two extremes of low and high likelihood


gen DR = 1 if driverB == 1
recode DR (. = 0) if driverW == 1
gen DS = 1 if driver_gender == "Male"
recode DS (.=0) if driver_gender == "Female"
gen DA = 1 if driver_age < 34
recode DA (.=0) if driver_age > 33
gen owm = 1 if offwm==1
recode owm (.=0) 
gen offyears = 1 if officer_years_of_service < 9
recode offyears (.=0) if officer_years_of_service > 8
gen stopinvest = 1 if safetystop==0
recode stopinvest (.=0) if safetystop==1
gen area1 = 0 if patrol == 10 | patrol == 9 | patrol == 7
recode area1 (.=1)
gen area2 = 1 if patrol == 6
recode area2 (.=0)
gen Target = DR+DS+DA+offwm+offyears+stopinvest+area1+area2

gen arrest=1 if result_of_stop=="Arrest"
recode arrest (.=0) if result_of_stop !=""
gen stop =1
gen drysearch =1 if search==1 & arrest ==0
recode drysearch (.=0) if search !=.
save Charlotte1617.dta, replace

*This completes data manipulation and variable creation from the raw file.
*Now turn to analysis in the order of presentation in the published article

use Charlotte1617.dta, clear
*Worst case scenarios, for introductory vignette in paper:
tab search if offwm==1 & drace==2 & gender==1 & driverLT35==1 &safetystop==0
tab search if offwm!=1 & drace==1 & gender==0 & driverLT35==0 &safetystop==1

tab arrest if offwm==1 & drace==2 & gender==1 & driverLT35==1 &safetystop==0
tab arrest if offwm!=1 & drace==1 & gender==0 & driverLT35==0 &safetystop==1

tab arrest if offwm==1 & drace==2 & gender==1 & driverLT35==1 &safetystop==0 & search==1
tab arrest if offwm!=1 & drace==1 & gender==0 & driverLT35==0 &safetystop==1 & search==1

tab drysearch if offwm==1 & drace==2 & gender==1 & driverLT35==1 &safetystop==0
tab drysearch if offwm!=1 & drace==1 & gender==0 & driverLT35==0 &safetystop==1

***End of vignettes

*Summarize officer race and gender, as share of all stops, for introductory materials
tab officer_race, miss
tab officer_gender, miss
tab offRG4, miss
tab patrol offRG4 , row
tab dRG8 offRG4 , row

***For Table 1:

tab search
tab search drace, col
tab search driver_gender, col
tab search driverLT35, col
tab search safetystop, col
tab search officer_race, col
tab search officer_gender, col
tab search offRG4, col miss
tab search officeryrs, col
tab search if owdw==1
tab search if owdb==1
tab search if owdo==1
tab search if obdw==1
tab search if obdb==1
tab patrol search , row

***End of Table 1

***For Table 1a, replicating this for arrest rather than search:

tab arrest
tab arrest drace, col
tab arrest driver_gender, col
tab arrest driverLT35, col
tab arrest safetystop, col
tab arrest officer_race, col
tab arrest officer_gender, col
tab arrest offRG4, col miss
tab arrest officeryrs, col
tab arrest if owdw==1
tab arrest if owdb==1
tab arrest if owdo==1
tab arrest if obdw==1
tab arrest if obdb==1
tab patrol arrest , row

***End of Table 1a


***For Table 1b, replicating this for fruitless searches:

tab drysearch
tab drysearch drace, col
tab drysearch driver_gender, col
tab drysearch driverLT35, col
tab drysearch safetystop, col
tab drysearch officer_race, col
tab drysearch officer_gender, col
tab drysearch offRG4, col miss
tab drysearch officeryrs, col
tab drysearch if owdw==1
tab drysearch if owdb==1
tab drysearch if owdo==1
tab drysearch if obdw==1
tab drysearch if obdb==1
tab patrol drysearch , row

***End of Table 1b

**Figure 1 on income and search rates

*First, get the census data on the Charlotte patrol districts in proper format, from the American Community Survey


*generate search and arrest rates by district

use Charlotte1617.dta, clear
collapse (sum) stop search arrest drysearch (last) patrol , by(cmpd_division)
gen searchrate = (search*100)/stop
gen arrestrate = (arrest*100)/stop
gen drysearchrate = (drysearch*100)/stop
drop if patrol==0
rename patrol District
save District-search-arrest-rates.dta, replace



import excel using TractsToDistricts.xlsx, sheet(Sheet2) firstrow clear
drop if District == .
rename TotalPopulation pop
rename AverageHouseholdIncomeIn201 inc
drop F
save Tracts.dta, replace

use Tracts.dta, clear
collapse (sum) pop , by(District)
rename pop DistrictPop
joinby District using Tracts.dta , unm(both)
gen PopShare = pop/DistrictPop
gen IncomeShare = PopShare*inc
collapse (sum) pop PopShare IncomeShare (last) Division, by(District)
rename IncomeShare Income
drop PopShare
gen IncomePerCapita = Income/pop
joinby District using District-search-arrest-rates.dta, unm(both)
save Districts.dta, replace

use Districts.dta, clear
drop _merge
joinby District using District-search-arrest-rates.dta, unm(both)
drop _merge
gen inc = Income/1000

format Income %9.0fc
#delimit ;
scatter searchrate inc,
mlstyle(color(gs0)) msymbol(circle) mfcolor(black) 
graphregion(color(white)) 
ylabel(0(3)12, nogrid)
yscale() 
ytitle("Percent") 
xscale()
xlabel(40(20)160)
xtitle("Average Household Income (Thousands)")
caption("")
title(A. Search, position(11) span)
;

graph save Fig1a.gph,  replace

#delimit ;
scatter arrestrate inc,
mlstyle(color(gs0)) msymbol(circle) mfcolor(black) 
graphregion(color(white)) 
ylabel(0(3)12, nogrid)
yscale() 
ytitle("Percent") 
xscale()
xlabel(40(20)160)
xtitle("Average Household Income (Thousands)")
caption("")
title(B. Arrest, position(11) span)
;

graph save  Fig1b.gph, replace


#delimit ;
scatter drysearchrate inc,
mlstyle(color(gs0)) msymbol(circle) mfcolor(black) 
graphregion(color(white)) 
ylabel(0(3)12, nogrid)
yscale() 
ytitle("Percent") 
xscale()
xlabel(40(20)160)
xtitle("Average Household Income  (Thousands)")
caption("")
title(C. Fruitless Search, position(11) span)
;

graph save  Fig1c.gph ,  replace

graph combine Fig1a.gph Fig1b.gph Fig1c.gph, graphregion(color(white)) colf r(1) col(3) xsize(6.5) ysize(2) ycommon altshrink
graph export "Fig1.png", width(3000) replace
graph export "Fig1.eps",  replace

corr searchrate arrestrate drysearchrate Income

***End of Figure 1.***

***Figure 2***

use Charlotte1617.dta, clear
gen wmstop = stop if offRG6==1
gen wmsearch = search if offRG6==1
gen wmarrest = arrest if offRG6==1
gen wmdrysearch = drysearch if offRG6==1
gen bmstop = stop if offRG6==3
gen bmsearch = search if offRG6==3
gen bmarrest = arrest if offRG6==3
gen bmdrysearch = drysearch if offRG6==3
gen driver = "White Male" if dRG8==5
replace driver = "Other Race Male" if dRG8>6
replace driver = "Black Male" if dRG8==6
replace driver = "White Female" if dRG8==1
replace driver = "Other Race Female" if dRG8> 2 & dRG8 < 5
replace driver = "Black Female" if dRG8==2

collapse (sum) wmstop wmsearch wmarrest wmdrysearch bmstop bmsearch bmarrest bmdrysearch, by(driver)
gen wmsearchrate=(wmsearch*100)/wmstop
gen wmarrestrate=(wmarrest*100)/wmstop
gen wmdrysearchrate=(wmdrysearch*100)/wmstop
gen bmsearchrate=(bmsearch*100)/bmstop
gen bmarrestrate=(bmarrest*100)/bmstop
gen bmdrysearchrate=(bmdrysearch*100)/wmstop
save OffDrivSearchArrestRates.dta, replace


use OffDrivSearchArrestRates, clear
gen order = 1 if driver == "White Male"
replace order = 2 if driver == "Other Race Male" 
replace order = 3 if driver == "Black Male" 
replace order = 4 if driver == "White Female" 
replace order = 5 if driver == "Other Race Female" 
replace order = 6 if driver == "Black Female" 



#delimit;
graph bar wmsearchrate bmsearchrate , over(driver, sort(order) label(angle(30) labsize(small)))
graphregion(color(white))
bar(1 , color(gs0))
bar(2 , color(gs12))
blabel(bar, format(%6.1f) size(small))
ytitle("Percent")
b1title("")
legend(off)
ylabel(, nogrid)
note("")
title(A. Search, position(11) span)
;

graph save  Fig2a.gph ,  replace


#delimit;
graph bar wmarrestrate bmarrestrate , over(driver, sort(order) label(angle(30) labsize(small)))
graphregion(color(white))
bar(1 , color(gs0))
bar(2 , color(gs12))
blabel(bar, format(%6.2f) size(small))
ytitle("Percent")
b1title("")
legend(off)
ylabel(, nogrid)
note("")
title(B. Arrest, position(11) span)
;

graph save  Fig2b.gph ,  replace


#delimit;
graph bar wmdrysearchrate bmdrysearchrate , over(driver, sort(order) label(angle(30) labsize(small)))
graphregion(color(white))
bar(1 , color(gs0))
bar(2 , color(gs12))
blabel(bar, format(%6.1f) size(small))
ytitle("Percent")
b1title("")
legend(off)
ylabel(, nogrid)
note("")
title(C. Fruitless Search, position(11) span)
;

graph save  Fig2c.gph ,  replace

graph combine Fig2a.gph Fig2b.gph Fig2c.gph, graphregion(color(white)) colf r(1) col(3) xsize(6.5) ysize(2) ycommon altshrink
graph export "Fig2.png", width(3000) replace
graph export "Fig2.eps", replace

***Table 2, logistic regressions


use Charlotte1617.dta, clear
logistic search offwm officer_years_of_service investstop driverLT35 i.dRG8  i.patrol
logistic arrest offwm officer_years_of_service investstop driverLT35 i.dRG8  i.patrol
logistic drysearch offwm officer_years_of_service investstop driverLT35 i.dRG8  i.patrol

*End of Table 2

***Figure 3, Predicted rates by Driver characteristics from Table 2

logistic search offwm i.dRG8a driverLT35 investstop officer_years_of_service i.patrol
margins dRG8a  , at((means) _all (max) driverLT35 offwm investstop (min) officer_years_of_service (asobserved) dRG8a ) post

#delimit ;
marginsplot , recast(scatter ) 
graphregion(color(white)) 
title("")
xtitle(Driver Race and Gender)
xlabel(1 "Black Male" 2 "Hispanic Male" 3 "White Male" 4 "Other Race Male"
5  "Black Female" 6 "White Female" 7 "Hispanic Female" 8 "Other Race Female", angle(30) labsize(small))
aspectratio(.5)
scheme(s1mono)
ylabel(, nogrid)
ytitle(Probability)
title(A. Search, position(11) span)
;

graph save Fig3a.gph, replace

***Arrest version of Figure 3
**Margins plots for predicted effects from Model 3 of Table 2
*for the table:
logistic arrest offwm driverLT35 investstop officer_years_of_service i.dRG8 i.patrol

*for the margins plot, with categories in different order
logistic arrest offwm i.dRG8a driverLT35 investstop officer_years_of_service i.patrol
margins dRG8a  , at((means) _all (max) driverLT35 offwm investstop (min) officer_years_of_service (asobserved) dRG8a ) post

#delimit ;
marginsplot , recast(scatter ) 
graphregion(color(white)) 
title("")
xtitle(Driver Race and Gender)
xlabel(1 "Black Male" 2 "Hispanic Male" 3 "White Male" 4 "Other Race Male"
5  "Black Female" 6 "White Female" 7 "Hispanic Female" 8 "Other Race Female", angle(30) labsize(small))
aspectratio(.5)
scheme(s1mono)
ylabel(, nogrid)
ytitle(Probability)
title(B. Arrest, position(11) span)
;

graph save Fig3b.gph, replace

***Fruitless search version of Figure 3
**Margins plots for predicted effects from Model 3 of Table 2
*for the table:
logistic drysearch offwm driverLT35 investstop officer_years_of_service i.dRG8 i.patrol

*for the margins plot, with categories in different order
logistic drysearch offwm i.dRG8a driverLT35 investstop officer_years_of_service i.patrol
margins dRG8a  , at((means) _all (max) driverLT35 offwm investstop (min) officer_years_of_service (asobserved) dRG8a ) post

#delimit ;
marginsplot , recast(scatter ) 
graphregion(color(white)) 
title("")
xtitle(Driver Race and Gender)
xlabel(1 "Black Male" 2 "Hispanic Male" 3 "White Male" 4 "Other Race Male"
5  "Black Female" 6 "White Female" 7 "Hispanic Female" 8 "Other Race Female", angle(30) labsize(small))
aspectratio(.5)
scheme(s1mono)
ylabel(, nogrid)
ytitle(Probability)
title(C. Fruitless Search, position(11) span)
;

graph save Fig3c.gph, replace

graph combine Fig3a.gph Fig3b.gph Fig3c.gph, graphregion(color(white)) colf r(1) col(3) xsize(6.5) ysize(2) ycommon altshrink
graph export "Fig3.png", width(3000) replace
graph export "Fig3.eps", replace


*Figure 4, officer characteristics varied
logistic search i.offRG6 i.dRG8a driverLT35 investstop officer_years_of_service i.patrol

margins offRG6  , at((means) _all (max) driverLT35  investstop (min) officer_years_of_service (asobserved) offRG6 ) post

#delimit ;
marginsplot , recast(scatter ) 
graphregion(color(white)) 
title("")
xtitle(Officer Race and Gender)
xlabel(1 "White Male" 2 "Other Race Male" 3 "Black Male" 4 "White Female" 5 "Other Race Female" 6 "Black Female" , labsize(small) angle(30))
aspectratio()
scheme(s1mono)
ylabel(, nogrid)
ytitle(Probability)
title(A. Search, position(11) span)
;

graph save Fig4a.gph, replace

***Arrest version:
*Figure 4, officer characteristics varied
logistic arrest i.offRG6 i.dRG8a driverLT35 investstop officer_years_of_service i.patrol

margins offRG6  , at((means) _all (max) driverLT35  investstop (min) officer_years_of_service (asobserved) offRG6 ) post

#delimit ;
marginsplot , recast(scatter ) 
graphregion(color(white)) 
title("")
xtitle(Officer Race and Gender)
xlabel(1 "White Male" 2 "Other Race Male" 3 "Black Male" 4 "White Female" 5 "Other Race Female" 6 "Black Female" , labsize(small) angle(30))
aspectratio()
scheme(s1mono)
ylabel(, nogrid)
ytitle(Probability)
title(B. Arrest, position(11) span)
;

graph save Fig4b.gph, replace

***Fruitless search version:
*Figure 4, officer characteristics varied
logistic drysearch i.offRG6 i.dRG8a driverLT35 investstop officer_years_of_service i.patrol

margins offRG6  , at((means) _all (max) driverLT35  investstop (min) officer_years_of_service (asobserved) offRG6 ) post

#delimit ;
marginsplot , recast(scatter ) 
graphregion(color(white)) 
title("")
xtitle(Officer Race and Gender)
xlabel(1 "White Male" 2 "Other Race Male" 3 "Black Male" 4 "White Female" 5 "Other Race Female" 6 "Black Female" , labsize(small) angle(30))
aspectratio()
scheme(s1mono)
ylabel(, nogrid)
ytitle(Probability)
title(C. Fruitless Search, position(11) span)
;

graph save Fig4c.gph, replace

graph combine Fig4a.gph Fig4b.gph Fig4c.gph, graphregion(color(white)) colf r(1) col(3) xsize(6.5) ysize(2) ycommon altshrink
graph export "Fig4.png", width(3000) replace
graph export "Fig4.eps", replace

*Table 3 and 4

tab DR search, row
tab DS search, row
tab DA search, row
tab owm search, row
tab offyears search, row
tab stopinvest search, row
tab area1 search, row
tab area2 search, row
tab Target search, row
*This leads to Figure 5a, see below

tab DR arrest, row
tab DS arrest, row
tab DA arrest, row
tab owm arrest, row
tab offyears arrest, row
tab stopinvest arrest, row
tab area1 arrest, row
tab area2 arrest, row
tab Target arrest, row
*This leads to Figure 5b, see below


tab DR drysearch, row
tab DS drysearch, row
tab DA drysearch, row
tab owm drysearch, row
tab offyears drysearch, row
tab stopinvest drysearch, row
tab area1 drysearch, row
tab area2 drysearch, row
tab Target drysearch, row
*This leads to Figure 5c, see below

gen search100 = search*100
gen arrest100 = arrest*100
gen drysearch100 = drysearch*100

*Figure 5
#delimit;
graph bar search100 , over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.1f))
ytitle("Percent")
b1title("Number of Targeted Characteristics")
legend()
ylabel(, nogrid)
title(A. Search, position(11) span)
;

graph save Fig5a.gph, replace
*Arrest

*Figure 5
#delimit;
graph bar arrest100 , over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.1f))
ytitle("Percent")
b1title("Number of Targeted Characteristics")
legend()
ylabel(, nogrid)
title(B. Arrest, position(11) span)
;

graph save Fig5b.gph, replace


*Fruitless Search

*Figure 5
#delimit;
graph bar drysearch100 , over(Target)
graphregion(color(white))
bar(1 ,  color(gs0))
blabel(bar, format(%6.1f))
ytitle("Percent")
b1title("Number of Targeted Characteristics")
legend()
ylabel(, nogrid)
title(C. Fruitless Search, position(11) span)
;

graph save Fig5c.gph, replace

graph combine Fig5a.gph Fig5b.gph Fig5c.gph, graphregion(color(white)) colf r(1) col(3) xsize(6.5) ysize(2) ycommon altshrink
graph export "Fig5.png", width(3000) replace
graph export "Fig5.eps", replace

*This completes the repliction file for the main text of the article.
*See OfficerCharacteristics-Appendix-Replication.do for the replication file for the on-line appendix

